==> rocketchatjavasdk-0.1.1-sources.jar: io/rocketchat/livechat/middleware/LiveChatMiddleware.java <==
package io.rocketchat.livechat.middleware;

import io.rocketchat.livechat.callback.*;
import io.rocketchat.livechat.model.AgentObject;
import io.rocketchat.livechat.model.GuestObject;
import io.rocketchat.livechat.model.LiveChatConfigObject;
import io.rocketchat.livechat.model.MessageObject;
import org.json.JSONArray;
import org.json.JSONObject;

import java.util.ArrayList;
import java.util.concurrent.ConcurrentHashMap;

/**
 * Created by sachin on 8/6/17.
 */

public class LiveChatMiddleware {


    //It will contain ConcurrentArrayList of all callback
    //Each new response will trigger each of the callback

    public enum AgentCallbackType{
        GETAGENTDATA,
        STREAMLIVECHATROOM
    }

    public enum CallbackType{
        GETINITIALDATA,
        REGISTER,
        LOGIN,
        GETCHATHISTORY,
        GETAGENTDATA
    }

    ConcurrentHashMap<Long,Object[]> callbacks;

    private static LiveChatMiddleware middleware= new LiveChatMiddleware();

    private LiveChatMiddleware(){
        callbacks= new ConcurrentHashMap<>();
    }

    public static LiveChatMiddleware getInstance(){
        return middleware;
    }

    public void createCallback(long i,Callback callback, CallbackType type){
        callbacks.put(i,new Object[]{callback,type});
    }

    public void processCallback(long i, JSONObject object){
        if (callbacks.containsKey(i)){
            Object[] objects=callbacks.remove(i);
            Callback callback= (Callback) objects[0];
            CallbackType type= (CallbackType) objects[1];
            switch (type) {
                case GETINITIALDATA:
                    InitialDataCallback dataCallback= (InitialDataCallback) callback;
                    LiveChatConfigObject liveChatConfigObject=new LiveChatConfigObject(object.optJSONObject("result"));
                    dataCallback.call(liveChatConfigObject);
                    break;
                case REGISTER: {
                    GuestCallback guestCallback = (GuestCallback) callback;
                    GuestObject guestObject = new GuestObject(object.optJSONObject("result"));
                    guestCallback.call(CallbackType.REGISTER, guestObject);
                }
                    break;
                case LOGIN:
                    GuestCallback guestCallback= (GuestCallback) callback;
                    GuestObject guestObject=new GuestObject(object.optJSONObject("result"));
                    guestCallback.call(CallbackType.LOGIN,guestObject);
                    break;
                case GETCHATHISTORY:
                    ArrayList <MessageObject> list=new ArrayList<MessageObject>();
                    HistoryCallback historymessages = (HistoryCallback) callback;
                    JSONArray array=object.optJSONObject("result").optJSONArray("messages");
                    for (int j=0;j<array.length();j++){
                        list.add(new MessageObject(array.optJSONObject(j)));
                    }
                    int unreadNotLoaded=object.optJSONObject("result").optInt("unreadNotLoaded");
                    historymessages.call(list,unreadNotLoaded);
                    break;
                case GETAGENTDATA:
                    AgentCallback agentCallback= (AgentCallback) callback;
                    AgentObject agentObject=new AgentObject(object.optJSONObject("result"));
                    agentCallback.call(AgentCallbackType.GETAGENTDATA,agentObject);
                    break;
            }

        }

    }
}

==> rocketchatjavasdk-0.3.0-sources.jar: io/rocketchat/livechat/middleware/LiveChatMiddleware.java <==
package io.rocketchat.livechat.middleware;

import io.rocketchat.livechat.callback.*;
import io.rocketchat.livechat.model.AgentObject;
import io.rocketchat.livechat.model.GuestObject;
import io.rocketchat.livechat.model.LiveChatConfigObject;
import io.rocketchat.livechat.model.MessageObject;
import org.json.JSONArray;
import org.json.JSONObject;

import java.util.ArrayList;
import java.util.concurrent.ConcurrentHashMap;

/**
 * Created by sachin on 8/6/17.
 */

public class LiveChatMiddleware {


    //It will contain ConcurrentArrayList of all callback
    //Each new response will trigger each of the callback

    public enum ListenerType {
        GETINITIALDATA,
        REGISTER,
        LOGIN,
        GETCHATHISTORY,
        GETAGENTDATA
    }

    ConcurrentHashMap<Long,Object[]> callbacks;

    private static LiveChatMiddleware middleware= new LiveChatMiddleware();

    private LiveChatMiddleware(){
        callbacks= new ConcurrentHashMap<>();
    }

    public static LiveChatMiddleware getInstance(){
        return middleware;
    }

    public void createCallback(long i, Listener listener, ListenerType type){
        callbacks.put(i,new Object[]{listener,type});
    }

    public void processCallback(long i, JSONObject object){
        if (callbacks.containsKey(i)){
            Object[] objects=callbacks.remove(i);
            Listener listener = (Listener) objects[0];
            ListenerType type= (ListenerType) objects[1];
            switch (type) {
                case GETINITIALDATA:
                    InitialDataListener dataListener= (InitialDataListener) listener;
                    LiveChatConfigObject liveChatConfigObject=new LiveChatConfigObject(object.optJSONObject("result"));
                    dataListener.onInitialData(liveChatConfigObject);
                    break;
                case REGISTER: {
                    AuthListener.RegisterListener registerListener = (AuthListener.RegisterListener) listener;
                    GuestObject guestObject = new GuestObject(object.optJSONObject("result"));
                    registerListener.onRegister(guestObject);
                }
                    break;
                case LOGIN:
                    AuthListener.LoginListener loginListener= (AuthListener.LoginListener) listener;
                    GuestObject guestObject=new GuestObject(object.optJSONObject("result"));
                    loginListener.onLogin(guestObject);
                    break;
                case GETCHATHISTORY:
                    ArrayList <MessageObject> list=new ArrayList<MessageObject>();
                    LoadHistoryListener historyListener = (LoadHistoryListener) listener;
                    JSONArray array=object.optJSONObject("result").optJSONArray("messages");
                    for (int j=0;j<array.length();j++){
                        list.add(new MessageObject(array.optJSONObject(j)));
                    }
                    int unreadNotLoaded=object.optJSONObject("result").optInt("unreadNotLoaded");
                    historyListener.onLoadHistory(list,unreadNotLoaded);
                    break;
                case GETAGENTDATA:
                    AgentListener.AgentDataListener agentDataListener = (AgentListener.AgentDataListener) listener;
                    AgentObject agentObject=new AgentObject(object.optJSONObject("result"));
                    agentDataListener.onAgentData(agentObject);
                    break;
            }

        }

    }
}
